@@ -308,22 +308,35 @@ class ObjectStore_SQLAlchemy(ObjectStore):
     else:
       self.objectPrefix = ""
 
-    connect_args = None
+    otherArgsForCreateEngine = {}
+    if "create_engine_args" in ConfigDict:
+      otherArgsForCreateEngine = ConfigDict["create_engine_args"]
+    else:
+      otherArgsForCreateEngine = {
+        "pool_recycle": 3600,
+        "pool_size": 40,
+        "max_overflow": 0
+      }
+      if "connect_args" in ConfigDict:
+        if ConfigDict["connect_args"] is not None:
+          otherArgsForCreateEngine["connect_args"] = ConfigDict["connect_args"]
+
     if "ssl_ca" in ConfigDict:
       #print("ssl_ca:", ConfigDict['ssl_ca'])
       if not os.path.isfile(ConfigDict['ssl_ca']):
         raise Exception("Supplied ssl_ca dosen't exist")
-      connect_args = {
-        "ssl": {'ca': ConfigDict['ssl_ca']}
-      }
+      if "connect_args" not in ConfigDict:
+        ConfigDict["connect_args"] = {}
 
-    #My experiment for SSL https://code.metcarob.com/node/249
-    #debugging https://github.com/PyMySQL/PyMySQL/blob/master/pymysql/connections.py
+      ConfigDict["connect_args"]["ssl"] = {'ca': ConfigDict['ssl_ca']}
 
-    if connect_args is None:
-      self.engine = create_engine(ConfigDict["connectionString"], pool_recycle=3600, pool_size=40, max_overflow=0)
-    else:
-      self.engine = create_engine(ConfigDict["connectionString"], pool_recycle=3600, pool_size=40, max_overflow=0, connect_args=connect_args)
+    if "poolclass" in otherArgsForCreateEngine:
+      if otherArgsForCreateEngine["poolclass"] == "StaticPool":
+        otherArgsForCreateEngine["poolclass"] = StaticPool
+
+    if detailLogging:
+      print("Creating connection with args:", otherArgsForCreateEngine)
+    self.engine = create_engine(ConfigDict["connectionString"], **otherArgsForCreateEngine)
 
     metadata = MetaData()
     #(objDICT, objectVersion, creationDate, lastUpdateDate)
